% sigma_w: le deviazione standard (per dimensione) del
%          rumore AWGN
% y: i campioni (un vettore di complessi) di statistica
%    sufficiente
% V: (vettore M x 1 di complessi) punti di costellazione
% bits: (matrice M x log2(M)) bit associati a ciascun punto
%       di costellazione
% L: (vettore log2(M) x numel(y)) Logaritmi dei rapporti di 
%    verosimiglianza associati ad y
%
function L = LLR_unmap(sigma_w,y,V,bits)
[M,bps] = size(bits);
L = zeros(bps,numel(y));

% ... calcolo degli LLR


% densità di probabilità delle componenti di rumore AWGN
% sul piano
function val = f_w(sigma_w,w)
val = exp(-abs(w).^2/(2*sigma_w^2))/(2*pi*sigma_w^2);
